Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeDuplicate ¶
func DeDuplicate[T comparable, R any](fn func(T) R) func(T) R
DeDuplicate creates a deduplicated version of the given function.
- fn: The function to deduplicate.
Returns a new function that behaves as a deduplicated version of `fn`.
func Debounce ¶
Debounce creates a debounced version of the given function.
- fn: The function to debounce. - duration: The debounce duration.
Returns a new function that behaves as a debounced version of `fn`.
func FirstNonEmpty
deprecated
func InsteadOfNil ¶
func InsteadOfNil[T any](a *T, b *T) *T
Types ¶
type ClosingProvider ¶
Click to show internal directories.
Click to hide internal directories.